@@ -1,67 +1,75 @@
 (**************************************************************************)
 (*                                                                        *)
-(*    Copyright 2012-2013 OCamlPro                                        *)
+(*    Copyright 2012-2015 OCamlPro                                        *)
 (*    Copyright 2012 INRIA                                                *)
 (*                                                                        *)
-(*  All rights reserved.This file is distributed under the terms of the   *)
-(*  GNU Lesser General Public License version 3.0 with linking            *)
-(*  exception.                                                            *)
-(*                                                                        *)
-(*  OPAM is distributed in the hope that it will be useful, but WITHOUT   *)
-(*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY    *)
-(*  or FITNESS FOR A PARTICULAR PURPOSE.See the GNU General Public        *)
-(*  License for more details.                                             *)
+(*  All rights reserved. This file is distributed under the terms of the  *)
+(*  GNU Lesser General Public License version 2.1, with the special       *)
+(*  exception on linking described in the file LICENSE.                   *)
 (*                                                                        *)
 (**************************************************************************)
 
-(** Applying solver solutions *)
+(** Interface with the solver, processing of full solutions through actions *)
 
 open OpamTypes
+open OpamStateTypes
 
 (** Resolve an user request *)
 val resolve:
-  ?verbose:bool ->
-  OpamState.state ->
+  'a switch_state ->
   user_action ->
-  requested:name_set ->
   orphans:package_set ->
+  ?reinstall:package_set ->
+  requested:name_set ->
   atom request ->
   (OpamSolver.solution, OpamCudf.conflict) result
 
-(** Apply a solution returned by the solver. If [ask] is not
-    specified, prompts the user whenever the solution isn't
-    obvious from the request *)
+(** Apply a solution returned by the solver. If [ask] is not specified, prompts
+    the user whenever the solution isn't obvious from the request. [add_roots]
+    defaults to the set of newly installed packages that are part of
+    [requested]. *)
 val apply:
   ?ask:bool ->
-  OpamState.state ->
+  rw switch_state ->
   user_action ->
   requested:OpamPackage.Name.Set.t ->
+  ?add_roots:OpamPackage.Name.Set.t ->
+  ?assume_built:bool ->
   OpamSolver.solution ->
-  solver_result
+  rw switch_state * solver_result
 
 (** Call the solver to get a solution and then call [apply]. If [ask] is not
     specified, prompts the user whenever the solution isn't obvious from the
-    request *)
+    request. [add_roots] defaults to the set of newly installed packages that
+    are part of [requested]. *)
 val resolve_and_apply:
   ?ask:bool ->
-  OpamState.state ->
+  rw switch_state ->
   user_action ->
-  requested:OpamPackage.Name.Set.t ->
   orphans:package_set ->
+  ?reinstall:package_set ->
+  requested:OpamPackage.Name.Set.t ->
+  ?add_roots:OpamPackage.Name.Set.t ->
+  ?assume_built:bool ->
   atom request ->
-  solver_result
+  rw switch_state * solver_result
 
-(** Raise an error if no solution is found or in case of error. *)
-val check_solution: OpamState.state -> solver_result -> unit
+(** Raise an error if no solution is found or in case of error. Unless [quiet]
+    is set, print a message indicating that nothing was done on an empty
+    solution. *)
+val check_solution: ?quiet:bool -> 'a switch_state -> solver_result -> unit
 
 (** {2 Atoms} *)
 
-(** Return an atom with a string version constraint *)
+(** Return an atom with a strict version constraint *)
 val eq_atom: name -> version -> atom
 
 (** Return a simple atom, with no version constrain, from a package*)
 val atom_of_package: package -> atom
 
+(** Returns an atom with a strict version constraint from a package *)
+val eq_atom_of_package: package -> atom
+
 (** Return a list of simple atoms (ie. with no version constraints)
     from a set of packages *)
 val atoms_of_packages: package_set -> atom list
@@ -73,13 +81,17 @@ val eq_atoms_of_packages: package_set -> atom list
     set. Displays an error and exits otherwise. [permissive] just changes the
     error message. *)
 val check_availability: ?permissive: bool ->
-  OpamState.state -> OpamPackage.Set.t -> atom list -> unit
+  'a switch_state -> OpamPackage.Set.t -> atom list -> unit
+
+(** Matches package names to their existing counterparts, up to capitalisation.
+    If no match exists, returns the name unchanged. *)
+val fuzzy_name: 'a switch_state -> name -> name
 
 (** Takes a "raw" list of atoms (from the user), and match it to existing
     packages. Match packages with the wrong capitalisation, and raises errors on
     non-existing packages, and unavailable ones unless [permissive] is set.
     Exits with a message on error. *)
-val sanitize_atom_list: ?permissive: bool -> OpamState.state -> atom list -> atom list
+val sanitize_atom_list: ?permissive: bool -> 'a switch_state -> atom list -> atom list
 
 (** {2 Stats} *)
 val sum: stats -> int
